@@ -58,6 +58,20 @@ class Element:
     def set(self, key, value):
         self.attrib[key] = value
 
+    def write(self, file):
+        assert self.tag is not None
+        file.write("<%s" % self.tag)
+        for k, v in self.attrib.items():
+            file.write(' {}="{}"'.format(k, v))
+        file.write(">")
+        if self.text is not None:
+            file.write(self.text)
+        for t in self._children:
+            t.write(file)
+        file.write("</%s>" % self.tag)
+        if self.tail is not None:
+            file.write(self.tail)
+
 
 class ElementTree:
 
@@ -67,6 +81,10 @@ class ElementTree:
     def getroot(self):
         return self.root
 
+    def write(self, file):
+        self.root.write(file)
+        file.write("\n")
+
 
 def parse_el(stream):
     stack = []
